@@ -1,5 +1,5 @@
 // ePDFView - A lightweight PDF Viewer.
-// Copyright (C) 2006 Emma's Software.
+// Copyright (C) 2006, 2007, 2009 Emma's Software.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -40,7 +40,6 @@ gboolean Config::m_LoadFile = TRUE;
 
 // Forward declarations.
 gchar *getConfigFileName (void);
-void makeDirWithParents (const gchar *);
 
 ///
 /// @brief Constructs a new Config object.
@@ -502,42 +501,9 @@ getConfigFileName ()
 {
     gchar *configDir = 
         g_build_filename (g_get_user_config_dir (), PACKAGE, NULL);
-    makeDirWithParents (configDir);
+    g_mkdir_with_parents (configDir, 0700);
     gchar *configFile = g_build_filename (configDir, "main.conf", NULL);
     g_free (configDir);
 
     return configFile;
 }
-
-///
-/// @brief Creates the directory and all its parent directories.
-///
-/// If the directory already exists it does nothing.
-///
-/// @param path The directory to create.
-///
-void
-makeDirWithParents (const gchar *path)
-{
-    // Get the list of directories to create.
-    GList *dirs = NULL;
-    gchar *dirName = g_strdup (path);
-    while ( !g_file_test (dirName, G_FILE_TEST_EXISTS) )
-    {
-        dirs = g_list_prepend (dirs, dirName);
-        dirName = g_path_get_dirname (dirName);
-    }
-
-    // Now create all of them.
-    GList *dir = g_list_first (dirs);
-    while ( NULL != dir )
-    {
-        if ( -1 == g_mkdir ((gchar *)dir->data, 0700) )
-        {
-            g_warning ("Couldn't make directory '%s'\n", (gchar *)dir->data);
-        }
-        g_free (dir->data);
-        dir = g_list_next (dir);
-    }
-    g_list_free (dirs);
-}
