@@ -167,6 +167,7 @@ PDFDocument::findTextInPage (gint pageNum, const gchar *textToFind)
                                        (height - matchRect->y1));
             results = g_list_prepend (results, rect);
         }
+        g_object_unref (G_OBJECT (page));
     }
 
     return g_list_reverse (results);
@@ -246,23 +247,25 @@ PDFDocument::loadFile (const gchar *filename, const gchar *password,
     // Check if the document couldn't be opened successfully and why.
     if ( NULL == newDocument )
     {
-        // Poppler's glib wrapper passes the Poppler error code unless the
-        // error is that the file is encrypted. We want to set our own
-        // error code in this case.
         DocumentError errorCode = DocumentErrorNone;
-        if ( POPPLER_ERROR == loadError->domain )
+        switch ( loadError->code )
         {
-            errorCode = DocumentErrorEncrypted;
-        }
-        else
-        {
-            // OK, the glib's wrapper don't pass the error code directly
-            // from Poppler. Instead returns G_FILE_ERROR_FAILED and a
-            // non translated string.
-            // Maybe I'm wrong (very probable) but that's a wrong way.
-            // So I'm reading the error code from the error string...
-            sscanf (loadError->message, "Failed to load document (error %d)",
-                    (gint *)&errorCode);
+            case POPPLER_ERROR_OPEN_FILE:
+            case POPPLER_ERROR_INVALID:
+                errorCode = DocumentErrorOpenFile;
+                break;
+
+            case POPPLER_ERROR_BAD_CATALOG:
+                errorCode = DocumentErrorBadCatalog;
+                break;
+
+            case POPPLER_ERROR_DAMAGED:
+                errorCode = DocumentErrorDamaged;
+                break;
+
+            case POPPLER_ERROR_ENCRYPTED:
+                errorCode = DocumentErrorEncrypted;
+                break;
         }
         g_error_free (loadError);
         // Get our error message.
@@ -324,7 +327,11 @@ PDFDocument::loadMetadata (void)
     gchar *format = NULL;
     gchar *keywords = NULL;
     PopplerPageLayout layout = POPPLER_PAGE_LAYOUT_UNSET;
+#if defined (HAVE_POPPLER_0_15_1)
+    gboolean *linearized = NULL;
+#else
     gchar *linearized = NULL;
+#endif
     GTime modDate;
     PopplerPageMode mode = POPPLER_PAGE_MODE_UNSET;
     gchar *producer = NULL;
@@ -603,23 +610,62 @@ PDFDocument::renderPage (gint pageNum)
     DocumentPage *renderedPage = new DocumentPage ();
     renderedPage->newPage (width, height);
 
-    // Create the pixbuf from the data and render to it.
-    GdkPixbuf *pixbuf = gdk_pixbuf_new_from_data (renderedPage->getData (),
-                                                  GDK_COLORSPACE_RGB,
-                                                  FALSE,
-                                                  PIXBUF_BITS_PER_SAMPLE,
-                                                  width, height,
-                                                  renderedPage->getRowStride (),
-                                                  NULL, NULL);
     PopplerPage *page = poppler_document_get_page (m_Document, pageNum - 1);
     if ( NULL != page )
     {
+#if defined (HAVE_POPPLER_0_17_0)
+        cairo_surface_t *surface = cairo_image_surface_create_for_data (
+                renderedPage->getData (),
+                CAIRO_FORMAT_RGB24, width, height,
+                renderedPage->getRowStride ());
+        cairo_t *context = cairo_create (surface);
+        cairo_save(context);
+        cairo_set_source_rgb (context, 1.0, 1.0, 1.0);
+        cairo_rectangle (context, 0, 0, width, height);
+        cairo_fill(context);
+        cairo_restore(context);
+        cairo_save(context);
+
+        switch(getRotation())
+        {
+            case 90:
+                cairo_translate(context, width, 0);
+                break;
+
+            case 180:
+                cairo_translate(context, width, height);
+                break;
+
+            case 270:
+                cairo_translate(context, 0, height);
+                break;
+
+            default:
+                cairo_translate(context, 0, 0);
+                break;
+        }
+
+        cairo_scale(context, getZoom(), getZoom());
+        cairo_rotate(context, getRotation() * G_PI / 180.0);
+        poppler_page_render (page, context);
+        cairo_destroy(context);
+        cairo_surface_destroy (surface);
+#else // !HAVE_POPPLER_0_17_0
+        // Create the pixbuf from the data and render to it.
+        GdkPixbuf *pixbuf = gdk_pixbuf_new_from_data (renderedPage->getData (),
+                                                      GDK_COLORSPACE_RGB,
+                                                      FALSE,
+                                                      PIXBUF_BITS_PER_SAMPLE,
+                                                      width, height,
+                                                      renderedPage->getRowStride (),
+                                                      NULL, NULL);
         poppler_page_render_to_pixbuf (page, 0, 0, width, height, getZoom (),
                                        getRotation (), pixbuf);
+        g_object_unref (pixbuf);
+#endif // HAVE_POPPLER_0_17_0
         setLinks (renderedPage, page);
         g_object_unref (G_OBJECT (page));
     }
-    g_object_unref (pixbuf);
 
     return (renderedPage);
 }
@@ -650,7 +696,11 @@ PDFDocument::saveFile (const gchar *filename, GError **error)
         return FALSE;
     }
     // Try to save the PDF document.
+#if defined (HAVE_POPPLER_0_8_0)
+    gboolean result = poppler_document_save_a_copy (m_Document, filename_uri, error);
+#else // !HAVE_POPPLER_0_8_0
     gboolean result = poppler_document_save (m_Document, filename_uri, error);
+#endif // HAVE_POPPLER_0_8_0
     g_free (filename_uri);
 
     return result;
@@ -678,14 +728,24 @@ PDFDocument::setTextSelection (DocumentRectangle *rect)
     gdouble pageWidth, pageHeight;
     poppler_page_get_size(page, &pageWidth, &pageHeight);
 
+#if defined (HAVE_POPPLER_0_15_0)
+    PopplerRectangle textRect = { rect->getX1() / getZoom(),
+                                  rect->getY1() / getZoom(),
+                                  rect->getX2() / getZoom(),
+                                  rect->getY2() / getZoom()};
+#else // !HAVE_POPPLER_0_15_0
     //for get text we must exchange y coordinate, don't ask me where logic here.
     PopplerRectangle textRect = { rect->getX1() / getZoom(),
                                   (pageHeight - rect->getY2() / getZoom()),
-                                  rect->getX2() * getZoom() / getZoom(),
+                                  rect->getX2() / getZoom(),
                                   (pageHeight - rect->getY1() / getZoom())};
+#endif // HAVE_POPPLER_0_15_0
     repairEmpty(textRect);
 
-#if defined (HAVE_POPPLER_0_6_0)
+#if defined (HAVE_POPPLER_0_15_0)
+    gchar *text = poppler_page_get_selected_text(page, POPPLER_SELECTION_GLYPH,
+            &textRect);
+#elif defined (HAVE_POPPLER_0_6_0)
     gchar *text = poppler_page_get_text(page, POPPLER_SELECTION_GLYPH,
             &textRect);
 #else // !HAVE_POPPLER_0_6_0
