@@ -26,6 +26,8 @@ using namespace ePDFView;
 
 // Constants
 static gint PAGE_VIEW_PADDING = 12;
+static gint SCROLL_PAGE_DRAG_LENGTH = 50;
+static const gint PIXBUF_BITS_PER_SAMPLE = 8;
 
 // Forwards declarations.
 static gboolean page_view_button_press_cb (GtkWidget *, GdkEventButton *,
@@ -239,6 +241,8 @@ PageView::setPresenter (PagePter *pter)
 void
 PageView::scrollPage (gdouble scrollX, gdouble scrollY, gint dx, gint dy)
 {
+    /* if the page cannot scroll and i'm dragging bottom to up, or left to right, 
+     i will go to the next page. viceversa previous page */
     GtkAdjustment *hAdjustment = gtk_scrolled_window_get_hadjustment (
             GTK_SCROLLED_WINDOW (m_PageScroll));
     gdouble hAdjValue = hAdjustment->page_size *
@@ -256,6 +260,23 @@ PageView::scrollPage (gdouble scrollX, gdouble scrollY, gint dx, gint dy)
             CLAMP (scrollY - vAdjValue,
                    vAdjustment->lower,
                    vAdjustment->upper - vAdjustment->page_size));
+    
+    /* if the page cannot scroll and i'm dragging bottom to up, or left to right, 
+       I will go to the next page. viceversa previous page */
+    if ( (scrollY == (vAdjustment->upper - vAdjustment->page_size) &&
+                dy < (-SCROLL_PAGE_DRAG_LENGTH) ) ||
+        (scrollX == (hAdjustment->upper - hAdjustment->page_size) &&
+         dx < (-SCROLL_PAGE_DRAG_LENGTH)) )
+    {
+        m_Pter->scrollToNextPage();
+        m_Pter->mouseButtonReleased(1);
+    }
+    else if( (scrollY == vAdjustment->lower && dy > SCROLL_PAGE_DRAG_LENGTH) ||
+        (scrollX == hAdjustment->lower && dx > SCROLL_PAGE_DRAG_LENGTH) )
+    {
+        m_Pter->scrollToPreviousPage();
+        m_Pter->mouseButtonReleased(1);
+    }
 }
 
 void 
@@ -398,7 +419,8 @@ GdkPixbuf *
 PageView::getPixbufFromPage (DocumentPage *page)
 {
     GdkPixbuf *pixbuf = gdk_pixbuf_new_from_data (page->getData (),
-            GDK_COLORSPACE_RGB, FALSE, 8, page->getWidth (), page->getHeight (),
+            GDK_COLORSPACE_RGB, page->hasAlpha(), PIXBUF_BITS_PER_SAMPLE,
+            page->getWidth (), page->getHeight (),
             page->getRowStride (), NULL, NULL);
     GdkPixbuf *finalPixbuf = gdk_pixbuf_copy (pixbuf);
     g_object_unref (pixbuf);
@@ -527,13 +549,6 @@ page_view_scrolled_cb (GtkWidget *widget, GdkEventScroll *event, gpointer data)
 {
     g_assert ( NULL != data && "The data parameter is NULL.");
 
-    // don't scroll when the CRTL-Button is down, because then the page should
-    // actually be zoomed and not scrolled. Zooming is handelt by the MainView
-    // class.
-    if ( event->state & GDK_CONTROL_MASK )
-    {
-        return FALSE;
-    }
     PagePter *pter = (PagePter *)data;
     GtkAdjustment *adjustment = 
         gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (widget));
@@ -662,10 +677,12 @@ page_view_keypress_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
        case GDK_KP_Enter:
             pter->scrollToNextPage ();
             direction = GTK_SCROLL_START;
+            break;
 
        case GDK_BackSpace:
-            pter->scrollToNextPage ();
+            pter->scrollToPreviousPage ();
             direction = GTK_SCROLL_START;
+            break;
 
        default:
             return FALSE;
