@@ -651,6 +651,14 @@ PrintView::createPrinterTab ()
     createPrinterListModel ();
     m_PrinterListView =
         gtk_tree_view_new_with_model (GTK_TREE_MODEL (m_PrinterList));
+
+    // Add scrollbars to treeview.
+    scrollBox = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollBox),
+      GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_container_add (GTK_CONTAINER (scrollBox), m_PrinterListView);
+    gtk_container_add (GTK_CONTAINER (mainBox), scrollBox);
+
     gtk_box_pack_start_defaults (GTK_BOX (mainBox), m_PrinterListView);
 
     {
