@@ -1,5 +1,5 @@
 // ePDFView - A lightweight PDF Viewer.
-// Copyright (C) 2006 Emma's Software.
+// Copyright (C) 2006, 2007, 2009 Emma's Software.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,11 +23,64 @@
 #include "epdfview.h"
 #include <MainView.h>
 
+#ifdef _WIN32
+#include <io.h>
+#include <conio.h>
+#define _WIN32_WINNT 0x0500
+#include <windows.h>
+#endif
+
 using namespace ePDFView;
 
+struct LoadFileInfo
+{
+    gchar *fileName;
+    MainPter *mainPter;
+    PDFDocument *document;
+};
+
+static int
+loadFileFromCommandLine (gpointer data)
+{
+    LoadFileInfo *info = static_cast<LoadFileInfo *> (data);
+
+    info->mainPter->setOpenState (info->fileName, FALSE);
+    info->document->load (info->fileName, NULL);
+
+    g_free (info->fileName);
+    delete info;
+
+    return FALSE;
+}
+
 int
 main (int argc, char **argv)
 {
+#ifdef _WIN32
+
+    if (fileno (stdout) != -1 &&
+ 	  _get_osfhandle (fileno (stdout)) != -1)
+    {
+      /* stdout is fine, presumably redirected to a file or pipe */
+    }
+    else
+    {
+      typedef BOOL (* WINAPI AttachConsole_t) (DWORD);
+
+      AttachConsole_t p_AttachConsole =
+        (AttachConsole_t) GetProcAddress (GetModuleHandle ("kernel32.dll"), "AttachConsole");
+
+      if (p_AttachConsole != NULL && p_AttachConsole (ATTACH_PARENT_PROCESS))
+      {
+          freopen ("CONOUT$", "w", stdout);
+          dup2 (fileno (stdout), 1);
+          freopen ("CONOUT$", "w", stderr);
+          dup2 (fileno (stderr), 2);
+
+      }
+    }
+#endif
+
     // Enable NLS.
     setlocale (LC_ALL, "");
     bindtextdomain (PACKAGE, LOCALEDIR);
@@ -56,13 +109,15 @@ main (int argc, char **argv)
     MainView *mainView = new MainView (mainPter);
     // Let know to the presenter which is its view.
     mainPter->setView (mainView);
-    // Enter the main loop and wait for user interaction. */
     // Now check if we have additional parameters. Any additional parameter
     // will be a file name to open.
     if ( argc > 1 )
     {
-        mainPter->setOpenState (argv[1], FALSE);
-        document->load (argv[1], NULL);
+        LoadFileInfo *info = new LoadFileInfo;
+        info->mainPter = mainPter;
+        info->document = document;
+        info->fileName = g_strdup (argv[1]);
+        g_idle_add (loadFileFromCommandLine, info);
     }
 
     gtk_main();
@@ -74,6 +129,8 @@ main (int argc, char **argv)
     // Save the configuration.
     Config::getConfig().save ();
 
+    g_option_context_free (optionContext);
+
     // All done!.
     return EXIT_SUCCESS;
 }
